@@ -8,7 +8,7 @@ use warnings;
 use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS $DEBUG);
 
 $DEBUG = 0;
-$VERSION = '0.41';
+$VERSION = '0.42';
 
 use base qw(Class::Accessor);
 XML::Sig->mk_accessors(qw(key));
@@ -671,14 +671,13 @@ sub _verify_x509_cert {
     my $self = shift;
     my ($cert, $canonical, $sig) = @_;
 
-    eval {
-        require Crypt::OpenSSL::RSA;
-    };
-
     # Decode signature and verify
     my $bin_signature = decode_base64($sig);
 
     if ($cert->key_alg_name eq 'id-ecPublicKey') {
+        eval {require Crypt::PK::ECC; CryptX->VERSION('0.036'); 1}
+        or confess "Crypt::PK::ECC 0.036+ needs to be installed so
+             that we can handle ECDSA signatures";
         my $ecdsa_pub = Crypt::PK::ECC->new(\$cert->pubkey);
 
         my $ecdsa_hash = $self->{rsa_hash};
@@ -691,6 +690,12 @@ sub _verify_x509_cert {
         }
     }
     else {
+        eval {
+            require Crypt::OpenSSL::RSA;
+        };
+        confess "Crypt::OpenSSL::RSA needs to be installed so
+                    that we can handle X509 certificates" if $@;
+
         my $rsa_pub = Crypt::OpenSSL::RSA->new_public_key($cert->pubkey);
 
         my $sig_hash = 'use_' . $self->{sig_hash} . '_hash';
@@ -772,6 +777,8 @@ sub _verify_dsa {
     eval {
         require Crypt::OpenSSL::DSA;
     };
+    confess "Crypt::OpenSSL::DSA needs to be installed so
+                    that we can handle DSA signatures" if $@;
 
     # Generate Public Key from XML
     my $p = decode_base64(_trim($self->{parser}->findvalue('dsig:P', $context)));
@@ -820,6 +827,9 @@ sub _verify_ecdsa {
     my $self = shift;
     my ($context,$canonical,$sig) = @_;
 
+    eval {require Crypt::PK::ECC; CryptX->VERSION('0.036'); 1}
+    or confess "Crypt::PK::ECC 0.036+ needs to be installed so
+             that we can handle ECDSA signatures";
     # Generate Public Key from XML
     my $oid = _trim($self->{parser}->findvalue('//dsig:NamedCurve/@URN', $context));
 
@@ -954,11 +964,9 @@ sub _load_ecdsa_key {
     my $self = shift;
     my $key_text = shift;
 
-    eval {
-        require Crypt::PK::ECC;
-    };
-
-    confess "Crypt::PK::ECC needs to be installed so that we can handle ECDSA keys." if $@;
+    eval {require Crypt::PK::ECC; CryptX->VERSION('0.036'); 1}
+    or confess "Crypt::PK::ECC 0.036+ needs to be installed so
+             that we can handle ECDSA signatures";
 
     my $ecdsa_key = Crypt::PK::ECC->new('t/ecdsa.private.pem');
 
@@ -1060,6 +1068,7 @@ sub _load_rsa_key {
     eval {
         require Crypt::OpenSSL::RSA;
     };
+    confess "Crypt::OpenSSL::RSA needs to be installed so that we can handle RSA keys." if $@;
 
     my $rsaKey = Crypt::OpenSSL::RSA->new_private_key( $key_text );
 
@@ -1110,6 +1119,8 @@ sub _load_x509_key {
     eval {
         require Crypt::OpenSSL::X509;
     };
+    confess "Crypt::OpenSSL::X509 needs to be installed so that we
+            can handle X509 Certificates." if $@;
 
     my $x509Key = Crypt::OpenSSL::X509->new_private_key( $key_text );
 
@@ -1409,7 +1420,7 @@ XML::Sig
 
 =head1 VERSION
 
-version 0.41
+version 0.42
 
 =head1 SYNOPSIS
 
